
/****************************************************************************/
/* Basic Types.  Need these to avoid differences in compilers...			*/
/* (And C is supposed to be a portable language!).							*/
/****************************************************************************/

typedef	signed		long	int	SLONG;		//32 bit signed.
typedef	unsigned	long	int	ULONG;		//32 bit unsigned.
typedef	signed		short	int	SWORD;		//16 bit signed.
typedef	unsigned	short	int	UWORD;		//16 bit unsigned.
typedef	signed		char		SBYTE;		//8 bit signed.
typedef	unsigned 	char		UBYTE;		//8 bit unsigned.
typedef	ULONG					BOOL;		//Yeah, should be a byte.
typedef	UBYTE					BBOOL;		//Most people define a bool as a long.  Bytes use less space and should be just as efficient.

#define		TRUE				1
#define		FALSE				0

/****************************************************************************/
/* Structures.																*/
/****************************************************************************/

typedef struct RealPointer
{
	UWORD			Segment;	//The real mode segment (offset is 0).
	UWORD			Selector;	//In protected mode, you need to chuck this dude into a segment register and use an offset 0.
} RealPointer;

typedef struct VesaInfo
{
	char		Signature[4];
	UWORD		Version;
	UWORD		OEMNameOffset;
	UWORD		OEMNameSegment;			//Pointer to OEM name?
	UBYTE		Capabilities[4];
	UWORD		SupportedModesOffset;
	UWORD		SupportedModesSegment;		//Pointer to list of supported VESA and OEM modes (terminated with 0xffff).
	UBYTE		Reserved[238];
} VesaInfo;

typedef struct VesaModeData
{
	UWORD		ModeAttributes;
	UBYTE		WindowAAttributes;
	UBYTE		WindowBAttributes;
	UWORD		WindowGranularity;
	UWORD		WindowSize;
	UWORD		StartSegmentWindowA;
	UWORD		StartSegmentWindowB;
	void		(*WindowPositioningFunction)(SLONG page);
	UWORD		BytesPerScanLine;

	//Remainder of this structure is optional for VESA modes in v1.0/1.1, needed for OEM modes.

	UWORD		PixelWidth;
	UWORD		PixelHeight;
	UBYTE		CharacterCellPixelWidth;
	UBYTE		CharacterCellPixelHeight;
	UBYTE		NumberOfMemoryPlanes;
	UBYTE		BitsPerPixel;
	UBYTE		NumberOfBanks;
	UBYTE		MemoryModelType;
	UBYTE		SizeOfBank;
	UBYTE		NumberOfImagePages;
	UBYTE		Reserved1;

	//VBE v1.2+

	UBYTE		RedMaskSize;
	UBYTE		RedFieldPosition;
	UBYTE		GreenMaskSize;
	UBYTE		GreenFieldPosition;
	UBYTE		BlueMaskSize;
	UBYTE		BlueFieldPosition;
	UBYTE		ReservedMaskSize;
	UBYTE		ReservedFieldPosition;
	UBYTE		DirectColourModeInfo;
	UBYTE		Reserved2[216];
} VesaModeData;

typedef struct RMREGS
{
	ULONG		edi;
	ULONG		esi;
	ULONG		ebp;
	ULONG		reserved;
	ULONG		ebx;
	ULONG		edx;
	ULONG		ecx;
	ULONG		eax;
	UWORD		flags;
	UWORD		es,ds,fs,gs,ip,cs,sp,ss;
} RMREGS;

/****************************************************************************/
/* Function prototypes.														*/
/****************************************************************************/

BBOOL	vesa_get_info(void);
void	vesa_free_info(void);
BBOOL	vesa_set_mode(UWORD vmode);
BBOOL	vesa_get_mode_info(UWORD vmode);
void	vesa_free_mode_info(void);
void	vesa_set_page(SLONG vpage);
void	vesa_screen_swap(UBYTE * source,SLONG swidth,SLONG sheight,SLONG bpp);

/****************************************************************************/
/* Global data externs.														*/
/****************************************************************************/

extern	SLONG			vesa_granularity;
extern	SLONG			vesa_page;
extern	SLONG			vesa_width;
extern	SLONG			vesa_height;
extern	SLONG			vesa_bits_per_pixel;

/****************************************************************************/
/* END																		*/
/****************************************************************************/

